@@ -1,15 +1,12 @@
 __author__ = 'Rens Holmer'
-__version__ = '0.0.11'
+__version__ = '0.0.14'
 
 from .tree import Tree  # noqa
 from .sequence import (  # noqa
     Alphabet,
-    DNA,
-    AMINO_ACID,
+    alphabets,
     Sequence,
     SequenceReader,
-    DNA,
-    AMINO_ACID,
     SequenceCollection,
     SequenceList,
     MultipleSequenceAlignment,
